function [T, V, W] = lancz(A, v, w, m) 
%% function [T, V, W] = lancz(A, v, w, m) 
%% performs k steps of Lanczos biorth. alg.
%% result will be a matrix T_m of size (m+1) x m
%% and orthogonal basis V[:,1:m+1] 
%% the relation A V_m = T_m V_{m+1} is satisfied.
%% T stores main diagonal then supper diagonal 
%% stored as (m+1) x m
%%
   T = zeros(m+1,m);
   t = w'*v; 
   tv = sqrt(abs(t));  
   tw = sign(t)*tv;
   v = v/tv;        w = w/tw; 
   beta = 0;        delta = 0.0;
   V(:,1)= v;       W(:,1) = w;
   vold = v;        wold = w;
   for k=1:m
       v1 = A *v - delta*vold ; 
       w1 = A'*w - beta*wold ; 
       alpha = v1'*w; 
       if (k>1) 
          T(k-1,k) = delta; 
       end
       T(k,k) = alpha; 
       v1 = v1 - alpha*v;   w1 = w1 - alpha*w;
       t = w1'*v1; 
       beta = sqrt(abs(t)); 
       delta = beta*sign(t); 
       vold = v;     wold = w;  
       v = v1/ beta; w = w1/delta ; 
       V(:,k+1) = v;        W(:,k+1) = w;
       T(k+1,k) = beta;
   end
       
 
